@@ -6,7 +6,7 @@
 # raise a `RecursionError`.
 # In order to avoid this, import only the API that you directly need like:
 #
-#   from .api.api_keys_api import ApiKeysApi
+#   from .api.api_clients_api import ApiClientsApi
 #
 # or import this package, but before doing it, use:
 #
@@ -14,10 +14,13 @@
 #   sys.setrecursionlimit(n)
 
 # Import APIs into API package:
-from delphix.api.gateway.api.api_keys_api import ApiKeysApi
+from delphix.api.gateway.api.api_clients_api import ApiClientsApi
+from delphix.api.gateway.api.bookmarks_api import BookmarksApi
 from delphix.api.gateway.api.d_sources_api import DSourcesApi
 from delphix.api.gateway.api.engines_api import EnginesApi
 from delphix.api.gateway.api.environments_api import EnvironmentsApi
+from delphix.api.gateway.api.jobs_api import JobsApi
 from delphix.api.gateway.api.management_api import ManagementApi
+from delphix.api.gateway.api.snapshots_api import SnapshotsApi
 from delphix.api.gateway.api.sources_api import SourcesApi
 from delphix.api.gateway.api.vdbs_api import VDBsApi
